//---------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                    (c) 1997-2010 European Space Agency
//
//---------------------------------------------------------------------------
//
//      checkemos.cc: --- test harness for epproc
//
//
//      CHANGE HISTORY:
//           AI, 2004-06-07: 1.0.0: - first version
//
//      REFERENCES:
//
//      AUTHOR:
//           A. Ibarra (AI), Mon Jun  7 11:39:01 CEST 2004
//
//      COMMENTS:
//           Due to problems with DAL and MacOS, we have had to change the test harness
//           for epproc package. The old test harness programs were written in perl, now
//           the test harness programs have been recoded in C++.
//     
//

#include <iostream>
#include <Dal.h>
#include <cassert>
#include <string>
#include <vector>

int main (int argc, char* argv[])
{

  if (argc != 2 )
    {
      std::cerr<<"Usage: "<<argv[0]<<" <expr> \n";
      return 1;
    }
  
  std::vector <std::string>  tables;
  tables.push_back("EVENTS");
  tables.push_back("EXPOSU01");
  tables.push_back("BADPIX01");
  tables.push_back("STDGTI01");
  tables.push_back("CALINDEX");

  std::string name(argv[1]);
  DataSet* set = dataSetServer->open(name, Dal::Read);

  for (unsigned i=0; i<tables.size() ; i++)
    {      
      if( set->table(tables[i]) )
	std::cout << tables[i] << std::endl; 
      else
	{
	  std::cerr << "table: tables[i] missing " << std::endl;
	  return 1;
	}
    }

  Table* tabEvents = set->table("EVENTS"); 
  std::cout << "EVENTS " << tabEvents->rows() << std::endl;

  // We run with randomize position on, so the number of extracted events
  // varies a bit.

  if ( tabEvents->attribute("INSTRUME")->asString() == "EMOS1")
    assert((tabEvents->rows() > 1400) && (tabEvents->rows() < 1465) );
  else if (  tabEvents->attribute("INSTRUME")->asString() == "EMOS2")
    assert((tabEvents->rows() > 1400) && (tabEvents->rows() < 1480) );
  
  Table* tabIndex = set->table("CALINDEX");
  assert(tabIndex->rows() == 96);
  
  dataSetServer->close(set);  
  return 0;
}
